%define anolis_release 2

# With annobin enabled, CRIU does not work anymore. It seems CRIU's
# parasite code breaks if annobin is enabled.
%undefine _annotated_build

# Disable automatic call to the set_build_flags macro
# at the beginning of the build, check, and install.
%undefine _auto_set_build_flags

Name: criu
Version: 3.19
Release: %{anolis_release}%{?dist}
Summary: Tool for Checkpoint/Restore in User-space
License: GPL-2.0-only AND LGPL-2.1-only AND MIT
URL: http://criu.org/
Source0: https://github.com/checkpoint-restore/criu/archive/v%{version}/criu-%{version}.tar.gz
Source1: criu-tmpfiles.conf

# Add protobuf-c as a dependency.
# We use this patch because the protobuf-c package name
# in RPM and DEB is different.
Patch99: criu.pc.patch

Patch100: 0001-port-to-riscv64.patch

BuildRequires: gcc
BuildRequires: systemd
BuildRequires: libnet-devel
BuildRequires: protobuf-devel protobuf-c-devel python3-devel libnl3-devel libcap-devel
BuildRequires: python3-setuptools
BuildRequires: python3-pip
BuildRequires: python3-wheel
BuildRequires: python3-protobuf
BuildRequires: asciidoctor
BuildRequires: perl-interpreter
BuildRequires: libselinux-devel
BuildRequires: gnutls-devel
# Checkpointing containers with a tmpfs requires tar
Recommends: tar
BuildRequires: make

%description
criu is the user-space part of Checkpoint/Restore in User-space
(CRIU), a project to implement checkpoint/restore functionality for
Linux in user-space.

%package devel
Summary: Header files and libraries for %{name}
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description devel
This package contains header files and libraries for %{name}.

%package libs
Summary: Libraries for %{name}
Requires: %{name} = %{version}-%{release}

%description libs
This package contains the libraries for %{name}

%package -n python3-%{name}
%{?python_provide:%python_provide python3-%{name}}
Summary: Python bindings for %{name}
Requires: python3-protobuf

%description -n python3-%{name}
python3-%{name} contains Python bindings for %{name}.

%package -n crit
Summary: CRIU image tool
Requires: python3-%{name} = %{version}-%{release}

%description -n crit
crit is a tool designed to decode CRIU binary dump files and show
their content in human-readable form.

%package -n criu-ns
Summary: Tool to run CRIU in different namespaces
Requires: %{name} = %{version}-%{release}

%description -n criu-ns
The purpose of the criu-ns wrapper script is to enable restoring a process
tree that might require a specific PID that is already used on the system.
This script can help to workaround the so called "PID mismatch" problem.

%package doc
Summary: Doc files for CRIU
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
Doc files for CRIU

%prep
%autosetup -p1

%build
# This package calls LD directly without specifying the LTO plugins.  Until
# that is fixed, disable LTO.
%define _lto_cflags %{nil}

CFLAGS+=`echo %{optflags} | sed -e 's,-fstack-protector\S*,,g'` make V=1 WERROR=0 PREFIX=%{_prefix} RUNDIR=/run/criu PYTHON=python3
make docs V=1

%install
sed -e "s,--upgrade --ignore-installed,--no-index --no-deps -v --no-build-isolation,g" -i lib/Makefile -i crit/Makefile
make install-criu DESTDIR=$RPM_BUILD_ROOT PREFIX=%{_prefix} LIBDIR=%{_libdir}
make install-lib DESTDIR=$RPM_BUILD_ROOT PREFIX=%{_prefix} LIBDIR=%{_libdir} PYTHON=python3
make install-crit DESTDIR=$RPM_BUILD_ROOT PREFIX=%{_prefix} LIBDIR=%{_libdir} PYTHON=python3
make install-man DESTDIR=$RPM_BUILD_ROOT PREFIX=%{_prefix} LIBDIR=%{_libdir}
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/compel.1
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/criu-amdgpu-plugin.1

mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 0644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -d -m 0755 %{buildroot}/run/%{name}/

# remove static lib
rm -f $RPM_BUILD_ROOT%{_libdir}/libcriu.a

%generate_compatibility_deps

%files
%{_sbindir}/%{name}
%{abidir}/%{name}-option.list
%doc %{_mandir}/man8/criu.8*
%{_libexecdir}/%{name}
%dir /run/%{name}
%{_tmpfilesdir}/%{name}.conf
%doc README.md COPYING

%files devel
%{_includedir}/criu
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files libs
%dir %{abidir}
%{_libdir}/*.so.*
%{abidir}/lib%{name}.dump

%files -n python3-%{name}
%{python3_sitelib}/pycriu*

%files -n crit
%{_bindir}/crit
%{python3_sitelib}/crit-%{version}.dist-info/
%{python3_sitelib}/crit
%doc %{_mandir}/man1/crit.1*

%files -n criu-ns
%{_sbindir}/criu-ns
%doc %{_mandir}/man1/criu-ns.1*

%files doc
%doc README.md INSTALL.md CONTRIBUTING.md MAINTAINERS_GUIDE.md

%changelog
* Wed Jun 18 2025 Shangtong Guo <guo.shangtong@zte.com.cn> - 3.19-2
- add support for riscv64

* Fri Feb 28 2025 Zhao Hang <wb-zh951434@alibaba-inc.com> - 3.19-1
- Update to 3.19-1 from 3.17.1-3
- Migrated to SPDX license
- Remove patches which is already in code and unneeded

* Mon Mar 11 2024 Bo Ren <rb01097748@alibaba-inc.com> - 3.17.1-3
- Rebuild with python3.11
- use pip install instead of setup.py install

* Mon Feb 13 2023 yuanhui <yuanhui@linux.alibaba.com> - 3.17.1-2
- add abi files

* Thu Sep 1 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.17.1-1
- update to 3.17.1

* Thu Mar 10 2022 Yuanhong Peng <yummypeng@linux.alibaba.com> - 3.16.1-1
- Init from upstream v3.16.1
